How to contribute — freeports_analysis 0.0.1 documentation

# How to contribute

The general workflow to contribute is:

1. forking the repository

2. making your edits to the code

3. submitting a pull request

Before doing so you need to setup your local repository

## Setting up the local repo

First thing clone locally your forked repository

    git clone <url-forked-repo>

then enter your local copy and initialize the repository launching from within the root folder of your repository

    contrib/init.sh

this script does:

- install the githooks of the project

- create a python virtual environment

- install the required packages for developing the project

## Contribute

Before making any contribution activate your developing virtual environment located in `venv/freeports-dev`. If you want to create other virtual environment, please do that in the gitignored `venv/` directory. To activate the virtual environment launch:

    source venv/freeports-dev/bin/activate

in other to deactivate it, just launch the `deactivate` command.

## Guidelines

- comment your code

- add the docstings in order to autogenerate the documentation

- type hint your code

- write tests for your code

- add meaningful commit messages (add the issue id if it refears to one)

- lint your code

## Contribution to the website

It is possible to contribute to the official website of the project from the specific GitHub repository.

## Resources

- How to Contribute to Open Source

- Using Pull Requests

- GitHub Help